@@ -4,12 +4,10 @@
 
 import importlib
 
-from src.githubdata import githubdata
-
 
 importlib.reload(githubdata)
 
-from src.githubdata.githubdata import *
+from src.githubdata.github_data_repo import *
 
 
 ## the most simple usage
@@ -18,16 +16,16 @@ df = get_data_from_github(u)
 
 ## clone a public repo
 u = 'https://github.com/imahdimir/d-TSETMC_ID-2-FirmTicker'
-repo = GithubData(u)
-repo.overwriting_clone()
+repo = GithubDataRepo(u)
+repo.clone_overwrite()
 
 ##
 repo.rmdir()
 
 ## clone a public repo and commit back
 u = 'https://github.com/imahdimir/test-public'
-repo = GithubData(u)
-repo.overwriting_clone()
+repo = GithubDataRepo(u)
+repo.clone_overwrite()
 
 ##
 msg = 'test commit'
@@ -38,8 +36,8 @@ repo.rmdir()
 
 ## clone a private repo and commit back
 ur = 'https://github.com/imahdimir/test-private'
-rp = GithubData(ur)
-rp.overwriting_clone()
+rp = GithubDataRepo(ur)
+rp.clone_overwrite()
 
 ##
 rp.commit_and_push('test commit')
